@@ -107,8 +107,8 @@ if not IS_WINDOWS:
   # Take the current user's UID and increment it by one, this counts as an
   # invalid UID, as the metric used is if the UID matches the current user's,
   # exactly.
-  INVALID_UID = LazyWrapper(lambda: sorted(
-      [user.pw_uid for user in pwd.getpwall()])[-1] + 1)
+  INVALID_UID = LazyWrapper(
+      lambda: sorted([user.pw_uid for user in pwd.getpwall()])[-1] + 1)
 
   # Note that because the system's GID mapping can change mid-test, tests that
   # check for specific errors should always re-fetch these GID-related values,
@@ -336,6 +336,21 @@ class GSMockBucketStorageUri(mock_storage_service.MockBucketStorageUri):
   def get_location(self, headers=None):
     return 'US'
 
+  def get_cors(self, headers=None):
+    return boto.gs.cors.Cors()
+
+  def get_encryption_config(self, headers=None):
+    return boto.gs.encryptionconfig.EncryptionConfig()
+
+  def get_lifecycle_config(self, headers=None):
+    return None
+
+  def get_website_config(self, headers=None):
+    return None
+
+  def get_versioning_config(self, headers=None):
+    return None
+
 
 TEST_BOTO_REMOVE_SECTION = 'TestRemoveSection'
 
@@ -403,7 +418,7 @@ def SequentialAndParallelTransfer(func):
     # Run the test normally once.
     func(*args, **kwargs)
 
-    if not RUN_S3_TESTS and UsingCrcmodExtension(crcmod):
+    if not RUN_S3_TESTS and UsingCrcmodExtension():
       # Try again, forcing parallel upload and sliced download.
       with SetBotoConfigForTest([
           ('GSUtil', 'parallel_composite_upload_threshold', '1'),
@@ -574,7 +589,7 @@ def GetTestNames():
 
 def is_file(obj):
   if six.PY2:
-    return isinstance(obj, file)
+    return isinstance(obj, file)  # pylint: disable=undefined-variable
   return isinstance(obj, io.IOBase)
 
 
@@ -632,6 +647,13 @@ def InvokedFromParFile():
   return 'zipimport' in loader.__class__.__module__
 
 
+def SkipForParFile(reason):
+  if InvokedFromParFile():
+    return unittest.skip(reason)
+  else:
+    return lambda func: func
+
+
 # Custom test callbacks must be pickleable, and therefore at global scope.
 class HaltingCopyCallbackHandler(object):
   """Test callback handler for intentionally stopping a resumable transfer."""
