@@ -12,13 +12,13 @@
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Author: Stig Sther Bakken <ssb@php.net>                             |
+   | Author: Stig Sæther Bakken <ssb@php.net>                             |
    +----------------------------------------------------------------------+
 */
 
 /* $Id$ */
 
-#define CONFIGURE_COMMAND " './configure'  '--with-layout=GNU' '--with-config-file-scan-dir=/usr/local/etc/php' '--disable-all' '--enable-libxml' '--with-libxml-dir=/usr/local' '--with-pcre-regex=/usr/local' '--program-prefix=' '--enable-mysqlnd' '--enable-fpm' '--with-fpm-user=www' '--with-fpm-group=www' '--enable-embed' '--enable-dtrace' '--prefix=/usr/local' '--localstatedir=/var' '--mandir=/usr/local/man' '--infodir=/usr/local/share/info/' '--build=i386-portbld-freebsd11.2' 'build_alias=i386-portbld-freebsd11.2' 'CFLAGS=-O2 -pipe -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing ' 'CPPFLAGS=' 'CPP=cpp' 'CXXFLAGS=-O2 -pipe -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing -DHARDENEDBSD -fPIE -fPIC '"
+#define CONFIGURE_COMMAND " './configure'  '--with-layout=GNU' '--with-config-file-scan-dir=/usr/local/etc/php' '--disable-all' '--enable-libxml' '--with-libxml-dir=/usr/local' '--with-pcre-regex=/usr/local' '--with-password-argon2=/usr/local' '--program-prefix=' '--enable-mysqlnd' '--enable-fpm' '--with-fpm-user=www' '--with-fpm-group=www' '--enable-embed' '--enable-dtrace' '--prefix=/usr/local' '--localstatedir=/var' '--mandir=/usr/local/man' '--infodir=/usr/local/share/info/' '--build=i386-portbld-freebsd11.2' 'build_alias=i386-portbld-freebsd11.2' 'CFLAGS=-O2 -pipe -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing ' 'CPPFLAGS=' 'CPP=cpp' 'CXXFLAGS=-O2 -pipe -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing -DHARDENEDBSD -fPIE -fPIC '"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -77,7 +77,7 @@
 #define PHP_BIRDSTEP_LIBS        ""
 #define PEAR_INSTALLDIR         ""
 #define PHP_INCLUDE_PATH	".:/usr/local/share/pear"
-#define PHP_EXTENSION_DIR       "/usr/local/lib/php/20160303"
+#define PHP_EXTENSION_DIR       "/usr/local/lib/php/20170718"
 #define PHP_PREFIX              "/usr/local"
 #define PHP_BINDIR              "/usr/local/bin"
 #define PHP_SBINDIR             "/usr/local/sbin"
@@ -89,3 +89,4 @@
 #define PHP_CONFIG_FILE_PATH    "/usr/local/etc"
 #define PHP_CONFIG_FILE_SCAN_DIR    "/usr/local/etc/php"
 #define PHP_SHLIB_SUFFIX        "so"
+#define PHP_SHLIB_EXT_PREFIX    ""
