@@ -51,6 +51,10 @@ options:
   api_password:
     description:
       - Password of the user to login into OpenNebula RPC server. If not set
+      - then the value of the C(ONE_PASSWORD) environment variable is used.
+      - if both I(api_username) or I(api_password) are not set, then it will try
+      - authenticate with ONE auth file. Default path is "~/.one/one_auth".
+      - Set environment variable C(ONE_AUTH) to override this path.
   template_name:
     description:
       - Name of VM template to use to create a new instace
@@ -158,8 +162,8 @@ options:
   disk_saveas:
     description:
       - Creates an image from a VM disk.
-      - It is a dictionary where you have to specife C(name) of the new image.
-      - Optionally you can specife C(disk_id) of the disk you want to save. By default C(disk_id) is 0.
+      - It is a dictionary where you have to specify C(name) of the new image.
+      - Optionally you can specify C(disk_id) of the disk you want to save. By default C(disk_id) is 0.
       - I(NOTE)':' This operation will only be performed on the first VM (if more than one VM ID is passed)
       - and the VM has to be in the C(poweredoff) state.
       - Also this operation will fail if an image with specified C(name) already exists.
@@ -358,44 +362,44 @@ instances:
     contains:
         vm_id:
             description: vm id
-            type: integer
+            type: int
             sample: 153
         vm_name:
             description: vm name
-            type: string
+            type: str
             sample: foo
         template_id:
             description: vm's template id
-            type: integer
+            type: int
             sample: 153
         group_id:
             description: vm's group id
-            type: integer
+            type: int
             sample: 1
         group_name:
             description: vm's group name
-            type: string
+            type: str
             sample: one-users
         owner_id:
             description: vm's owner id
-            type: integer
+            type: int
             sample: 143
         owner_name:
             description: vm's owner name
-            type: string
+            type: str
             sample: app-user
         mode:
             description: vm's mode
-            type: string
+            type: str
             returned: success
             sample: 660
         state:
             description: state of an instance
-            type: string
+            type: str
             sample: ACTIVE
         lcm_state:
             description: lcm state of an instance that is only relevant when the state is ACTIVE
-            type: string
+            type: str
             sample: RUNNING
         cpu:
             description: Percentage of CPU divided by 100
@@ -407,11 +411,11 @@ instances:
             sample: 2
         memory:
             description: The size of the memory in MB
-            type: string
+            type: str
             sample: 4096 MB
         disk_size:
             description: The size of the disk in MB
-            type: string
+            type: str
             sample: 20480 MB
         networks:
             description: a list of dictionaries with info about IP, NAME, MAC, SECURITY_GROUPS for each NIC
@@ -432,7 +436,7 @@ instances:
                     ]
         uptime_h:
             description: Uptime of the instance in hours
-            type: integer
+            type: int
             sample: 35
         labels:
             description: A list of string labels that are associated with the instance
@@ -460,44 +464,44 @@ tagged_instances:
     contains:
         vm_id:
             description: vm id
-            type: integer
+            type: int
             sample: 153
         vm_name:
             description: vm name
-            type: string
+            type: str
             sample: foo
         template_id:
             description: vm's template id
-            type: integer
+            type: int
             sample: 153
         group_id:
             description: vm's group id
-            type: integer
+            type: int
             sample: 1
         group_name:
             description: vm's group name
-            type: string
+            type: str
             sample: one-users
         owner_id:
             description: vm's user id
-            type: integer
+            type: int
             sample: 143
         owner_name:
             description: vm's user name
-            type: string
+            type: str
             sample: app-user
         mode:
             description: vm's mode
-            type: string
+            type: str
             returned: success
             sample: 660
         state:
             description: state of an instance
-            type: string
+            type: str
             sample: ACTIVE
         lcm_state:
             description: lcm state of an instance that is only relevant when the state is ACTIVE
-            type: string
+            type: str
             sample: RUNNING
         cpu:
             description: Percentage of CPU divided by 100
@@ -509,11 +513,11 @@ tagged_instances:
             sample: 2
         memory:
             description: The size of the memory in MB
-            type: string
+            type: str
             sample: 4096 MB
         disk_size:
             description: The size of the disk in MB
-            type: string
+            type: str
             sample: 20480 MB
         networks:
             description: a list of dictionaries with info about IP, NAME, MAC, SECURITY_GROUPS for each NIC
@@ -534,7 +538,7 @@ tagged_instances:
                     ]
         uptime_h:
             description: Uptime of the instance in hours
-            type: integer
+            type: int
             sample: 35
         labels:
             description: A list of string labels that are associated with the instance
@@ -610,12 +614,12 @@ def get_vm_by_id(client, vm_id):
     # -2: All vms user can Use
     # -1: Vms belonging to the user and any of his groups - default
     # >= 0: UID User's vms
-    pool.info(filter=-2)
+    pool.info(filter=-2, range_start=int(vm_id), range_end=int(vm_id))
 
-    for vm in pool:
-        if str(vm.id) == str(vm_id):
-            return vm
-    return None
+    if len(pool) == 1:
+        return pool[0]
+    else:
+        return None
 
 
 def get_vms_by_ids(module, client, state, ids):
@@ -1219,8 +1223,8 @@ def get_connection_info(module):
     if not password:
         password = os.environ.get('ONE_PASSWORD')
 
-    if not(url and username and password):
-        module.fail_json(msg="One or more connection parameters (api_url, api_username, api_password) were not specified")
+    if not url:
+        module.fail_json(msg="Opennebula API url (api_url) is not specified")
     from collections import namedtuple
 
     auth_params = namedtuple('auth', ('url', 'username', 'password'))
@@ -1308,7 +1312,10 @@ def main():
     count_labels = params.get('count_labels')
     disk_saveas = params.get('disk_saveas')
 
-    client = oca.Client(auth.username + ':' + auth.password, auth.url)
+    if not (auth.username and auth.password):
+        client = oca.Client(None, auth.url)
+    else:
+        client = oca.Client(auth.username + ':' + auth.password, auth.url)
 
     if attributes:
         attributes = dict((key.upper(), value) for key, value in attributes.items())
@@ -1330,20 +1337,20 @@ def main():
     template_id = None
     if requested_template_id or requested_template_name:
         template_id = get_template_id(module, client, requested_template_id, requested_template_name)
-        if not template_id:
+        if template_id is None:
             if requested_template_id:
                 module.fail_json(msg='There is no template with template_id: ' + str(requested_template_id))
             elif requested_template_name:
                 module.fail_json(msg="There is no template with name: " + requested_template_name)
 
-    if exact_count and not template_id:
+    if exact_count and template_id is None:
         module.fail_json(msg='Option `exact_count` needs template_id or template_name')
 
     if exact_count is not None and not (count_attributes or count_labels):
         module.fail_json(msg='Either `count_attributes` or `count_labels` has to be specified with option `exact_count`.')
     if (count_attributes or count_labels) and exact_count is None:
         module.fail_json(msg='Option `exact_count` has to be specified when either `count_attributes` or `count_labels` is used.')
-    if template_id and state != 'present':
+    if template_id is not None and state != 'present':
         module.fail_json(msg="Only state 'present' is valid for the template")
 
     if memory:
@@ -1358,7 +1365,7 @@ def main():
     if exact_count is not None and exact_count < 0:
         module.fail_json(msg='`exact_count` cannot be less than 0')
     if count <= 0:
-        module.fail_json(msg='`count` has to be grater than 0')
+        module.fail_json(msg='`count` has to be greater than 0')
 
     if permissions is not None:
         import re
@@ -1371,7 +1378,7 @@ def main():
                                                                                    count_attributes, labels, count_labels, disk_size,
                                                                                    networks, hard, wait, wait_timeout)
         vms = tagged_instances_list
-    elif template_id and state == 'present':
+    elif template_id is not None and state == 'present':
         # Deploy count VMs
         changed, instances_list, tagged_instances_list = create_count_of_vms(module, client, template_id, count,
                                                                              attributes, labels, disk_size, networks, wait, wait_timeout)
