@@ -1,12 +1,15 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2014-2018 Miroslav Stampar (@stamparm)
+Copyright (c) 2014-2019 Maltrail developers (https://github.com/stamparm/maltrail/)
 See the file 'LICENSE' for copying permission
 """
+from __future__ import print_function
 
 # simple ignore rule mechanism configured by file 'misc/ignore_event.txt' and/or user defined `USER_IGNORELIST`
 
+import re
+
 from core.settings import config
 from core.settings import IGNORE_EVENTS
 
@@ -14,6 +17,9 @@ def ignore_event(event_tuple):
     retval = False
     _, _, src_ip, src_port, dst_ip, dst_port, _, _, _, _, _ = event_tuple
 
+    if config.IGNORE_EVENTS_REGEX and re.search(config.IGNORE_EVENTS_REGEX, repr(event_tuple), re.I):
+        retval = True
+
     for ignore_src_ip, ignore_src_port, ignore_dst_ip, ignore_dst_port in IGNORE_EVENTS:
         if ignore_src_ip != '*' and ignore_src_ip != src_ip :
             continue
@@ -27,6 +33,6 @@ def ignore_event(event_tuple):
         break
 
     if retval and config.SHOW_DEBUG:
-        print("[i] ignore_event src_ip=%s, src_port=%s, dst_ip=%s, dst_port=%s" % (src_ip, src_port, dst_ip, dst_port)) 
+        print("[i] ignore_event src_ip=%s, src_port=%s, dst_ip=%s, dst_port=%s" % (src_ip, src_port, dst_ip, dst_port))
 
     return retval
