@@ -28,7 +28,6 @@
  */
 
 require_once("guiconfig.inc");
-require_once("services.inc") ;
 require_once("interfaces.inc");
 require_once("system.inc");
 require_once("plugins.inc.d/dyndns.inc");
@@ -51,7 +50,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     if (isset($_GET['id']) && !empty($a_dyndns[$_GET['id']])) {
         $id = $_GET['id'];
     }
-    $config_copy_fieldnames = array('username', 'password', 'host', 'mx', 'type', 'zoneid', 'ttl', 'updateurl',
+    $config_copy_fieldnames = array('username', 'password', 'host', 'mx', 'type', 'zoneid','resourceid', 'ttl', 'updateurl',
                                     'resultmatch', 'requestif', 'descr', 'interface');
     foreach ($config_copy_fieldnames as $fieldname) {
         if (isset($id) && isset($a_dyndns[$id][$fieldname])) {
@@ -76,7 +75,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     }
     $input_errors = array();
     $pconfig = $_POST;
-    if(($pconfig['type'] == "freedns" || $pconfig['type'] == "namecheap") && $pconfig['username'] == "") {
+    if(($pconfig['type'] == "freedns" || $pconfig['type'] == "linode" || $pconfig['type'] == "linode-v6" || $pconfig['type'] == "namecheap") && $pconfig['username'] == "") {
         $pconfig['username'] = "none";
     }
 
@@ -85,12 +84,20 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     $reqdfieldsn = array();
     $reqdfields = array('type');
     $reqdfieldsn = array(gettext('Service type'));
-    if ($pconfig['type'] != 'custom' && $pconfig['type'] != 'custom-v6') {
+
+    if (in_array($pconfig['type'], array('azure', 'azurev6'))) {
+        $reqdfields[] = 'password';
+        $reqdfieldsn[] = gettext('Password');
+        $reqdfields[] = 'resourceid';
+        $reqdfieldsn[] = gettext('Resource Id');
+        $reqdfields[] = 'ttl';
+        $reqdfieldsn[] = gettext('TTL');
+    } elseif ($pconfig['type'] != 'custom' && $pconfig['type'] != 'custom-v6') {
         $reqdfields[] = 'host';
         $reqdfieldsn[] = gettext('Hostname');
         $reqdfields[] = 'username';
         $reqdfieldsn[] = gettext('Username');
-        if (!in_array($pconfig['type'], array('duckdns', 'regfish', 'regfish-v6'))) {
+        if (!in_array($pconfig['type'], array('dynv6', 'dynv6-v6', 'duckdns', 'regfish', 'regfish-v6'))) {
             $reqdfields[] = 'password';
             $reqdfieldsn[] = gettext('Password');
         }
@@ -102,11 +109,20 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     do_input_validation($pconfig, $reqdfields, $reqdfieldsn, $input_errors);
 
     if (isset($pconfig['host']) && in_array('host', $reqdfields)) {
-        /* Namecheap can have a @. or *. in hostname */
-        if ($pconfig['type'] == "namecheap" && (substr($pconfig['host'], 0, 2) == '@.' || substr($pconfig['host'], 0, 2) == '*.')) {
-            $host_to_check = substr($pconfig['host'], 2);
-        } else {
-            $host_to_check = $pconfig['host'];
+        $host_to_check = $pconfig['host'];
+
+        switch ($pconfig['type']) {
+            case 'cloudflare':
+            case 'cloudflare-v6':
+            case 'eurodns':
+            case 'googledomains':
+            case 'linode':
+            case 'linode-v6':
+            case 'namecheap':
+                $host_to_check = preg_replace('/^[@*]\./', '', $host_to_check);
+                break;
+            default:
+                break;
         }
 
         if (!is_domain($host_to_check)) {
@@ -136,6 +152,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         $dyndns['enable'] = !empty($pconfig['enable']);
         $dyndns['interface'] = $pconfig['interface'];
         $dyndns['zoneid'] = $pconfig['zoneid'];
+        $dyndns['resourceid'] = $pconfig['resourceid'];
         $dyndns['ttl'] = $pconfig['ttl'];
         $dyndns['updateurl'] = $pconfig['updateurl'];
         // Trim hard-to-type but sometimes returned characters
@@ -191,6 +208,10 @@ include("head.inc");
               case "route53-v6":
                 $(".type_route53").show();
                 break;
+              case "azure":
+              case "azurev6":
+                $(".type_azure").show();
+                break;
               default:
                 $(".type_default").show();
                 break;
@@ -323,9 +344,11 @@ include("head.inc");
                     <td>
                       <input name="username" type="text" id="username" value="<?= $pconfig['username'] ?>" />
                       <div class="hidden" data-for="help_for_username">
-                        <?= gettext("Username is required for all types except Namecheap, FreeDNS and Custom Entries.");?>
+                        <?= gettext('Username is required except when stated otherwise.') ?>
                         <br /><?= gettext('Route 53: Enter your Access Key ID.') ?>
                         <br /><?= gettext('Duck DNS: Enter your Token.') ?>
+                        <br /><?= gettext('dynv6: Enter your Token.') ?>
+                        <br /><?= gettext('Azure: Enter your Azure AD application ID.') ?>
                         <br /><?= gettext('For Custom Entries, Username and Password represent HTTP Authentication username and passwords.') ?>
                       </div>
                     </td>
@@ -338,6 +361,9 @@ include("head.inc");
                         <?=gettext('FreeDNS (freedns.afraid.org): Enter your "Authentication Token" provided by FreeDNS.') ?>
                         <br /><?= gettext('Route 53: Enter your Secret Access Key.') ?>
                         <br /><?= gettext('Duck DNS: Leave blank.') ?>
+                        <br /><?= gettext('dynv6: Leave blank.') ?>
+                        <br /><?= gettext('Azure: client secret of the AD application') ?>
+                        <br /><?= gettext('Linode: Enter your Personal Access Token.') ?>
                       </div>
                     </td>
                   </tr>
@@ -350,6 +376,15 @@ include("head.inc");
                       </div>
                     </td>
                   </tr>
+                  <tr class="opt_field type_azure">
+                    <td><a id="help_for_resourceid" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?= gettext('Resource Id') ?></td>
+                    <td>
+                      <input name="resourceid" type="text" id="resourceid" value="<?= $pconfig['resourceid'] ?>" />
+                      <div class="hidden" data-for="help_for_resourceid">
+                        <?= gettext("Enter the resource id of the DNS Zone in Azure.") ?>
+                      </div>
+                    </td>
+                  </tr>
                   <tr class="opt_field type_custom">
                     <td><a id="help_for_updateurl" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Update URL") ?></td>
                     <td>
@@ -378,7 +413,7 @@ include("head.inc");
                       </div>
                     </td>
                   </tr>
-                  <tr class="opt_field type_route53">
+                  <tr class="opt_field type_route53  type_azure">
                     <td><a id="help_for_ttl" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("TTL");?></td>
                     <td>
                       <input name="ttl" type="text" id="ttl" value="<?= $pconfig['ttl'] ?>" />
@@ -397,12 +432,10 @@ include("head.inc");
                     <td>&nbsp;</td>
                     <td>
                       <button name="submit" type="submit" class="btn btn-primary" value="save"><?= gettext('Save') ?></button>
-<?php
-                      if (isset($id)): ?>
+<?php if (isset($id)): ?>
                         <button name="force" type="submit" class="btn btn-primary" value="force"><?= gettext('Save and Force Update') ?></button>
                         <input name="id" type="hidden" value="<?= $id ?>" />
-<?php
-                      endif; ?>
+<?php endif ?>
                       <a href="services_dyndns.php" class="btn btn-default"><?= gettext('Cancel') ?></a>
                     </td>
                   </tr>
@@ -422,4 +455,6 @@ include("head.inc");
       </div>
     </div>
   </section>
-<?php include("foot.inc"); ?>
+<?php
+
+include("foot.inc");
