@@ -1,44 +1,46 @@
 <?php
 
 /*
-    Copyright (C) 2014-2015 Deciso B.V.
-    Copyright (C) 2008 Shrew Soft Inc. <mgrooms@shrew.net>
-    All rights reserved.
-
-    Redistribution and use in source and binary forms, with or without
-    modification, are permitted provided that the following conditions are met:
-
-    1. Redistributions of source code must retain the above copyright notice,
-       this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above copyright
-       notice, this list of conditions and the following disclaimer in the
-       documentation and/or other materials provided with the distribution.
-
-    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
-    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
-    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-    POSSIBILITY OF SUCH DAMAGE.
-*/
+ * Copyright (C) 2014-2015 Deciso B.V.
+ * Copyright (C) 2008 Shrew Soft Inc. <mgrooms@shrew.net>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ */
 
 require_once("guiconfig.inc");
-require_once("plugins.inc.d/openvpn.inc");
-require_once("services.inc");
 require_once("interfaces.inc");
+require_once("plugins.inc.d/openvpn.inc");
 
 $a_server = &config_read_array('openvpn', 'openvpn-server');
 
 $act = null;
 if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     // fetch id if provided
-    if (isset($_GET['id']) && is_numericint($_GET['id'])) {
+    if (isset($_GET['dup']) && isset($a_server[$_GET['dup']]))  {
+        $configId = $_GET['dup'];
+    } elseif (isset($_GET['id']) && is_numericint($_GET['id'])) {
         $id = $_GET['id'];
+        $configId = $id;
     }
     if (isset($_GET['act'])) {
         $act = $_GET['act'];
@@ -50,8 +52,8 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     $pconfig['digest'] = "SHA1"; // OpenVPN Defaults to SHA1 if unset
     $pconfig['autokey_enable'] = "yes";
     $pconfig['autotls_enable'] = "yes";
-    if ($act == "edit" && isset($id) && isset($a_server[$id])) {
-        if ($a_server[$id]['mode'] != "p2p_shared_key") {
+    if (isset($configId) && isset($a_server[$configId])) {
+        if ($a_server[$configId]['mode'] != "p2p_shared_key") {
             $pconfig['cert_depth'] = 1;
         }
 
@@ -66,12 +68,12 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             ,ntp_server2,netbios_enable,netbios_ntype,netbios_scope,wins_server1
             ,wins_server2,no_tun_ipv6,push_register_dns,dns_domain,local_group
             ,client_mgmt_port,verbosity_level,caref,crlref,certref,dh_length
-            ,cert_depth,strictusercn,digest,disable,duplicate_cn,vpnid,reneg-sec,use-common-name";
+            ,cert_depth,strictusercn,digest,disable,duplicate_cn,vpnid,reneg-sec,use-common-name,cso_login_matching";
 
         foreach (explode(",", $copy_fields) as $fieldname) {
             $fieldname = trim($fieldname);
-            if (isset($a_server[$id][$fieldname])) {
-                $pconfig[$fieldname] = $a_server[$id][$fieldname];
+            if (isset($a_server[$configId][$fieldname])) {
+                $pconfig[$fieldname] = $a_server[$configId][$fieldname];
             } elseif (!isset($pconfig[$fieldname])) {
               // initialize element
                 $pconfig[$fieldname] = null;
@@ -79,27 +81,28 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         }
 
         // load / convert
-        if (!empty($a_server[$id]['ipaddr'])) {
-            $pconfig['interface'] = $pconfig['interface'] . '|' . $a_server[$id]['ipaddr'];
+        if (!empty($a_server[$configId]['ipaddr'])) {
+            $pconfig['interface'] = $pconfig['interface'] . '|' . $a_server[$configId]['ipaddr'];
         }
-        if (!empty($a_server[$id]['shared_key'])) {
-            $pconfig['shared_key'] = base64_decode($a_server[$id]['shared_key']);
+        if (!empty($a_server[$configId]['shared_key'])) {
+            $pconfig['shared_key'] = base64_decode($a_server[$configId]['shared_key']);
         } else {
             $pconfig['shared_key'] = null;
         }
-        if (!empty($a_server[$id]['tls'])) {
+        if (!empty($a_server[$configId]['tls'])) {
             $pconfig['tlsauth_enable'] = "yes";
-            $pconfig['tls'] = base64_decode($a_server[$id]['tls']);
+            $pconfig['tls'] = base64_decode($a_server[$configId]['tls']);
         } else {
             $pconfig['tls'] = null;
             $pconfig['tlsauth_enable'] = null;
         }
     } elseif ($act == "new") {
         $pconfig['tlsauth_enable'] = "yes";
-        $pconfig['dh_length'] = 1024;
+        $pconfig['dh_length'] = 2048;
         $pconfig['dev_mode'] = "tun";
-        $pconfig['interface'] = "wan";
-        $pconfig['local_port'] = openvpn_port_next('UDP');
+        $pconfig['interface'] = 'any';
+        $pconfig['protocol'] = 'UDP';
+        $pconfig['local_port'] = openvpn_port_next($pconfig['protocol']);
         $pconfig['pool_enable'] = "yes";
         $pconfig['cert_depth'] = 1;
         // init all fields used in the form
@@ -113,7 +116,8 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             ,ntp_server2,netbios_enable,netbios_ntype,netbios_scope,wins_server1
             ,wins_server2,no_tun_ipv6,push_register_dns,dns_domain
             ,client_mgmt_port,verbosity_level,caref,crlref,certref,dh_length
-            ,cert_depth,strictusercn,digest,disable,duplicate_cn,vpnid,shared_key,tls,reneg-sec,use-common-name";
+            ,cert_depth,strictusercn,digest,disable,duplicate_cn,vpnid,shared_key,tls,reneg-sec,use-common-name
+            ,cso_login_matching";
         foreach (explode(",", $init_fields) as $fieldname) {
             $fieldname = trim($fieldname);
             if (!isset($pconfig[$fieldname])) {
@@ -192,37 +196,39 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             $input_errors[] = gettext("You must select a Backend for Authentication if the server mode requires User Auth.");
         }
 
-        if ($result = openvpn_validate_port($pconfig['local_port'], 'Local port')) {
+        if ($result = openvpn_validate_port($pconfig['local_port'], gettext('Local port'))) {
             $input_errors[] = $result;
         }
 
-        if ($result = openvpn_validate_cidr($pconfig['tunnel_network'], 'IPv4 Tunnel Network', false, "ipv4")) {
+        if ($result = openvpn_validate_cidr($pconfig['tunnel_network'], gettext('IPv4 Tunnel Network'), false, 'ipv4')) {
             $input_errors[] = $result;
         }
 
-        if ($result = openvpn_validate_cidr($pconfig['tunnel_networkv6'], 'IPv6 Tunnel Network', false, "ipv6")) {
+        if ($result = openvpn_validate_cidr($pconfig['tunnel_networkv6'], gettext('IPv6 Tunnel Network'), false, 'ipv6')) {
             $input_errors[] = $result;
         }
 
-        if ($result = openvpn_validate_cidr($pconfig['remote_network'], 'IPv4 Remote Network', true, "ipv4")) {
+        if ($result = openvpn_validate_cidr($pconfig['remote_network'], gettext('IPv4 Remote Network'), true, 'ipv4')) {
             $input_errors[] = $result;
         }
 
-        if ($result = openvpn_validate_cidr($pconfig['remote_networkv6'], 'IPv6 Remote Network', true, "ipv6")) {
+        if ($result = openvpn_validate_cidr($pconfig['remote_networkv6'], gettext('IPv6 Remote Network'), true, 'ipv6')) {
             $input_errors[] = $result;
         }
 
-        if ($result = openvpn_validate_cidr($pconfig['local_network'], 'IPv4 Local Network', true, "ipv4")) {
+        if ($result = openvpn_validate_cidr($pconfig['local_network'], gettext('IPv4 Local Network'), true, 'ipv4')) {
             $input_errors[] = $result;
         }
 
-        if ($result = openvpn_validate_cidr($pconfig['local_networkv6'], 'IPv6 Local Network', true, "ipv6")) {
+        if ($result = openvpn_validate_cidr($pconfig['local_networkv6'], gettext('IPv6 Local Network'), true, 'ipv6')) {
             $input_errors[] = $result;
         }
 
-        $portused = openvpn_port_used($pconfig['protocol'], $pconfig['interface'], $pconfig['local_port'], $vpnid);
-        if (($portused != $vpnid) && ($portused != 0)) {
-            $input_errors[] = gettext("The specified 'Local port' is in use. Please select another value");
+        if (!empty($pconfig['local_port'])) {
+            $portused = openvpn_port_used($pconfig['protocol'], $pconfig['interface'], $pconfig['local_port'], $vpnid);
+            if ($portused != $vpnid && $portused != 0) {
+                $input_errors[] = gettext("The specified 'Local port' is in use. Please select another value");
+            }
         }
 
         if (!$tls_mode && empty($pconfig['autokey_enable'])) {
@@ -275,7 +281,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         }
 
         if (!empty($pconfig['client_mgmt_port_enable'])) {
-            if ($result = openvpn_validate_port($pconfig['client_mgmt_port'], 'Client management port')) {
+            if ($result = openvpn_validate_port($pconfig['client_mgmt_port'], gettext('Client management port'))) {
                 $input_errors[] = $result;
             }
         }
@@ -294,11 +300,14 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             $reqdfieldsn = array(gettext('Shared key'));
         }
 
+        $reqdfields[] = 'local_port';
+        $reqdfieldsn[] = gettext('Local port');
+
         if ($pconfig['dev_mode'] != "tap") {
-            $reqdfields[] = 'tunnel_network';
-            $reqdfieldsn[] = gettext('Tunnel network');
+            $reqdfields[] = 'tunnel_network,tunnel_networkv6';
+            $reqdfieldsn[] = gettext('Tunnel Network');
         } else {
-            if ($pconfig['serverbridge_dhcp'] && $pconfig['tunnel_network']) {
+            if ($pconfig['serverbridge_dhcp'] && ($pconfig['tunnel_network'] || $pconfig['tunnel_networkv6'])) {
                 $input_errors[] = gettext("Using a tunnel network and server bridge settings together is not allowed.");
             }
             if (($pconfig['serverbridge_dhcp_start'] && !$pconfig['serverbridge_dhcp_end'])
@@ -318,6 +327,24 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         if (isset($pconfig['reneg-sec']) && $pconfig['reneg-sec'] != "" && (string)((int)$pconfig['reneg-sec']) != $pconfig['reneg-sec']) {
             $input_errors[] = gettext("Renegotiate time should contain a valid number of seconds.");
         }
+
+        // When server certificate is set, check type.
+        if (!empty($pconfig['certref'])) {
+            foreach ($config['cert'] as $cert) {
+                if ($cert['refid'] == $pconfig['certref']) {
+                    if (cert_get_purpose($cert['crt'])['server'] == 'No') {
+                        $input_errors[] = gettext(
+                            sprintf("certificate %s is not intended for server use", $cert['descr'])
+                        );
+                    }
+                }
+            }
+        }
+        $prev_opt = (isset($id) && !empty($a_server[$id])) ? $a_server[$id]['custom_options'] : "";
+        if ($prev_opt != str_replace("\r\n", "\n", $pconfig['custom_options']) && !userIsAdmin($_SESSION['Username'])) {
+            $input_errors[] = gettext('Advanced options may only be edited by system administrators due to the increased possibility of privilege escalation.');
+        }
+
         do_input_validation($pconfig, $reqdfields, $reqdfieldsn, $input_errors);
 
         if (count($input_errors) == 0) {
@@ -325,7 +352,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             $server = array();
 
             // delete(rename) old interface so a new TUN or TAP interface can be created.
-            if (isset($id) && $pconfig['dev_mode'] <> $a_server[$id]['dev_mode']) {
+            if (isset($id) && $pconfig['dev_mode'] != $a_server[$id]['dev_mode']) {
                 openvpn_delete('server', $a_server[$id]);
             }
             // 1 on 1 copy of config attributes
@@ -337,7 +364,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
                 ,serverbridge_dhcp_end,dns_domain,dns_server1,dns_server2,dns_server3
                 ,dns_server4,push_register_dns,ntp_server1,ntp_server2,netbios_enable
                 ,netbios_ntype,netbios_scope,no_tun_ipv6,verbosity_level,wins_server1
-                ,wins_server2,client_mgmt_port,strictusercn,reneg-sec,use-common-name";
+                ,wins_server2,client_mgmt_port,strictusercn,reneg-sec,use-common-name,cso_login_matching";
 
             foreach (explode(",", $copy_fields) as $fieldname) {
                 $fieldname = trim($fieldname);
@@ -401,7 +428,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             write_config();
 
             openvpn_configure_single($server['vpnid']);
-            openvpn_configure_csc();
 
             header(url_safe('Location: /vpn_openvpn_server.php'));
             exit;
@@ -413,9 +439,11 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
 
 include("head.inc");
 
-$main_buttons = array(
-    array('href'=>'vpn_openvpn_server.php?act=new', 'label'=>gettext("add server")),
-);
+$main_buttons = array();
+
+if (empty($act)) {
+    $main_buttons[] = array('href' => 'vpn_openvpn_server.php?act=new', 'label' => gettext('Add'));
+}
 
 legacy_html_escape_form_data($pconfig);
 
@@ -469,6 +497,7 @@ $( document ).ready(function() {
               $(".opt_gwredir").hide();
           }
           $("#dev_mode").change();
+          $('.selectpicker').selectpicker('refresh');
           $(window).resize();
       });
       $("#mode").change();
@@ -491,6 +520,7 @@ $( document ).ready(function() {
               $("#serverbridge_dhcp_start").prop('disabled', false);
               $("#serverbridge_dhcp_end").prop('disabled', false);
           }
+          $('.selectpicker').selectpicker('refresh');
       });
       $("#dev_mode").change();
 
@@ -603,7 +633,7 @@ $( document ).ready(function() {
                       </td>
                     </tr>
                     <tr>
-                      <td class="vncellreq">
+                      <td>
                         <a id="help_for_disable" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Disabled"); ?>
                       </td>
                       <td>
@@ -627,7 +657,7 @@ $( document ).ready(function() {
                     <tr>
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Server Mode");?></td>
                         <td>
-                        <select name='mode' id="mode" class="form-control">
+                        <select name='mode' id="mode" class="selectpicker">
 <?php
                       $openvpn_server_modes = array(
                         'p2p_tls' => gettext("Peer to Peer ( SSL/TLS )"),
@@ -649,7 +679,7 @@ $( document ).ready(function() {
                     <tr class="opt_mode opt_mode_server_user opt_mode_server_tls_user" style="display:none">
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Backend for authentication");?></td>
                       <td>
-                        <select name='authmode[]' id='authmode' class="form-control" multiple="multiple" size="5">
+                        <select name='authmode[]' id='authmode' class="selectpicker" multiple="multiple" size="5">
 <?php
                         if (isset($pconfig['authmode'])) {
                             $authmodes = explode(",", $pconfig['authmode']);
@@ -671,7 +701,7 @@ $( document ).ready(function() {
                     <tr class="opt_mode opt_mode_server_user opt_mode_server_tls_user" style="display:none">
                       <td><a id="help_for_local_group" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?= gettext('Enforce local group') ?></td>
                       <td>
-                        <select name='local_group' id="local_group" class="form-control">
+                        <select name='local_group' id="local_group" class="selectpicker">
                           <option value="" <?= empty($pconfig['local_group']) ? 'selected="selected"' : '' ?>>(<?= gettext('none') ?>)</option>
 <?php
                         foreach (config_read_array('system', 'group') as $group):
@@ -687,11 +717,11 @@ $( document ).ready(function() {
                       </td>
                     </tr>
                     <tr>
-                      <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Protocol");?></td>
+                      <td><a id="help_for_protocol" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Protocol");?></td>
                         <td>
-                          <select name='protocol' class="form-control">
+                          <select name='protocol' class="selectpicker">
 <?php
-                          foreach (array("UDP", "UDP6", "TCP", "TCP6") as $prot) :
+                          foreach (openvpn_get_protocols() as $prot):
                               $selected = "";
                               if ($pconfig['protocol'] == $prot) {
                                   $selected = "selected=\"selected\"";
@@ -700,12 +730,17 @@ $( document ).ready(function() {
 <?php
                           endforeach; ?>
                         </select>
+                        <div class="hidden" data-for="help_for_protocol">
+                          <?= gettext('Select the protocol family to be used. Note that using both families with UDP/TCP ' .
+                                      'does not work with an explicit interface as OpenVPN does not support listening to more ' .
+                                      'than one specified IP address. In this case IPv4 is currently assumed.') ?>
+                        </div>
                       </td>
                     </tr>
                     <tr>
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Device Mode"); ?></td>
                       <td>
-                        <select name="dev_mode" id="dev_mode" class="form-control">
+                        <select name="dev_mode" id="dev_mode" class="selectpicker">
 <?php
                         foreach (array("tun", "tap") as $device) :
                                $selected = "";
@@ -727,7 +762,7 @@ $( document ).ready(function() {
                     <tr>
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Interface"); ?></td>
                       <td>
-                        <select name="interface" class="form-control">
+                        <select name="interface" class="selectpicker" data-size="5" data-live-search="true">
 <?php
                         $interfaces = get_configured_interface_with_descr();
                         $carplist = get_configured_carp_interface_list();
@@ -737,18 +772,6 @@ $( document ).ready(function() {
                                                     $aliaslist = get_configured_ip_aliases_list();
                         foreach ($aliaslist as $aliasip => $aliasif) {
                             $interfaces[$aliasif.'|'.$aliasip] = $aliasip." (".get_vip_descr($aliasip).")";
-                        }
-                                                    $grouplist = return_gateway_groups_array();
-                        foreach ($grouplist as $name => $group) {
-                            if ($group['ipprotocol'] != "inet") {
-                                continue;
-                            }
-                            if ($group[0]['vip'] <> "") {
-                                $vipif = $group[0]['vip'];
-                            } else {
-                                $vipif = $group[0]['int'];
-                            }
-                            $interfaces[$name] = "GW Group {$name}";
                         }
                         $interfaces['lo0'] = "Localhost";
                         $interfaces['any'] = "any";
@@ -761,7 +784,7 @@ $( document ).ready(function() {
                           <option value="<?=$iface; ?>"<?=$selected;?>><?=htmlspecialchars($ifacename);?></option>
 <?php
                         endforeach; ?>
-                        </select> <br />
+                        </select>
                       </td>
                     </tr>
                     <tr>
@@ -807,7 +830,7 @@ endif; ?>
                         <td>
 <?php
                         if (isset($config['ca'])) :?>
-                          <select name='caref' class="form-control">
+                          <select name='caref' class="selectpicker" data-size="5" data-live-search="true">
 <?php
                           foreach ($config['ca'] as $ca) :
                               $selected = "";
@@ -834,7 +857,7 @@ endif; ?>
                       <td>
 <?php
                         if (isset($config['crl'])) :?>
-                        <select name='crlref' class="form-control">
+                        <select name='crlref' class="selectpicker" data-size="5" data-live-search="true">
                           <option value="">None</option>
 <?php
                           foreach ($config['crl'] as $crl) :
@@ -862,13 +885,16 @@ endif; ?>
                       <td>
 <?php
                       if (isset($config['cert'])) :?>
-                        <select name='certref' class="form-control">
+                        <select name='certref' class="selectpicker" data-size="5" data-live-search="true">
 <?php
                         foreach ($config['cert'] as $cert) :
                             $selected = "";
                             $caname = "";
                             $inuse = "";
                             $revoked = "";
+                            if (!isset($cert['prv'])) {
+                                continue;
+                            }
                             if (isset($cert['caref'])) {
                                 $ca = lookup_ca($cert['caref']);
                                 if (!empty($ca)) {
@@ -902,21 +928,18 @@ endif; ?>
                     <tr class="opt_mode opt_mode_p2p_tls opt_mode_server_tls opt_mode_server_user opt_mode_server_tls_user">
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("DH Parameters Length"); ?></td>
                       <td>
-                        <select name="dh_length" class="form-control">
+                        <select name="dh_length" class="selectpicker">
 <?php
-                        foreach (array(1024, 2048, 4096) as $length) :
+                        foreach (list_dh_parameters() as $length):
                             $selected = "";
                             if ($length == $pconfig['dh_length']) {
-                                $selected = " selected=\"selected\"";
+                                $selected = ' selected="selected"';
                             }
                         ?>
-                          <option<?=$selected?>><?=$length;?></option>
+                          <option value="<?= html_safe($length) ?>" <?=$selected?>><?= sprintf(gettext('%s bit'), $length) ?></option>
 <?php
                         endforeach; ?>
                         </select>
-                        <span>
-                          <?=gettext("bits"); ?>
-                        </span>
                       </td>
                     </tr>
                     <tr class="opt_mode opt_mode_p2p_shared_key">
@@ -939,7 +962,7 @@ endif; ?>
                     <tr>
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Encryption algorithm"); ?></td>
                       <td>
-                        <select name="crypto" class="form-control">
+                        <select name="crypto" class="selectpicker">
 <?php
                         $cipherlist = openvpn_get_cipherlist();
                         foreach ($cipherlist as $name => $desc) :
@@ -959,7 +982,7 @@ endif; ?>
                     <tr>
                       <td><a id="help_for_digest" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Auth Digest Algorithm"); ?></td>
                       <td>
-                        <select name="digest" class="form-control">
+                        <select name="digest" class="selectpicker" data-size="5" data-live-search="true">
 <?php
                         $digestlist = openvpn_get_digestlist();
                         foreach ($digestlist as $name => $desc) :
@@ -982,7 +1005,7 @@ endif; ?>
                     <tr id="engine">
                       <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Hardware Crypto"); ?></td>
                       <td>
-                        <select name="engine" class="form-control">
+                        <select name="engine" class="selectpicker" data-size="5" data-live-search="true">
 <?php
                         $engines = openvpn_get_engines();
                         foreach ($engines as $name => $desc) :
@@ -1004,7 +1027,7 @@ endif; ?>
                       <td>
                         <table>
                         <tr><td>
-                        <select name="cert_depth" class="form-control">
+                        <select name="cert_depth" class="selectpicker">
                           <option value=""><?=gettext('Do Not Check') ?></option>
 <?php
                           $openvpn_cert_depths = array(
@@ -1061,7 +1084,7 @@ endif; ?>
                     </tr>
                     <tr>
                       <td style="width:22%" id="ipv4_tunnel_network"><a id="help_for_tunnel_network" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("IPv4 Tunnel Network"); ?></td>
-                      <td witdh="78%">
+                      <td style="width:78%">
                         <input name="tunnel_network" type="text" class="form-control unknown" size="20" value="<?=$pconfig['tunnel_network'];?>" />
                         <div class="hidden" data-for="help_for_tunnel_network">
                             <?=gettext("This is the IPv4 virtual network used for private " .
@@ -1103,7 +1126,7 @@ endif; ?>
                     <tr class="dev_mode dev_mode_tap">
                       <td style="width:22%"><a id="help_for_serverbridge_interface" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Bridge Interface"); ?></td>
                       <td>
-                        <select id="serverbridge_interface" name="serverbridge_interface" class="form-control">
+                        <select id="serverbridge_interface" name="serverbridge_interface" class="selectpicker" data-size="5" data-live-search="true">
 <?php
                         $serverbridge_interface['none'] = "none";
                         $serverbridge_interface = array_merge($serverbridge_interface, get_configured_interface_with_descr());
@@ -1238,9 +1261,9 @@ endif; ?>
                     <tr>
                       <td style="width:22%"><a id="help_for_compression" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Compression"); ?></td>
                       <td>
-                        <select name="compression" class="form-control">
+                        <select name="compression" class="selectpicker">
 <?php
-                        foreach ($openvpn_compression_modes as $cmode => $cmodedesc) :
+                        foreach (openvpn_compression_modes() as $cmode => $cmodedesc):
                             $selected = "";
                             if ($cmode == $pconfig['compression']) {
                                 $selected = " selected=\"selected\"";
@@ -1434,7 +1457,7 @@ endif; ?>
                           <span>
                             <?=gettext("Node Type"); ?>:&nbsp;
                           </span>
-                          <select name='netbios_ntype' class="form-control">
+                          <select name='netbios_ntype' class="selectpicker">
 <?php
                           foreach ($netbios_nodetypes as $type => $name) :
                               $selected = "";
@@ -1526,7 +1549,8 @@ endif; ?>
                     <tr>
                       <td style="width:22%"><a id="help_for_custom_options" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Advanced"); ?></td>
                       <td>
-                        <textarea rows="6" cols="78" name="custom_options" id="custom_options"><?=$pconfig['custom_options'];?></textarea><br />
+                        <textarea rows="6" cols="78" name="custom_options" id="custom_options"><?=$pconfig['custom_options'];?></textarea>
+                        <?=gettext("This option will be removed in the future due to being insecure by nature. In the mean time only full administrators are allowed to change this setting.");?>
                         <div class="hidden" data-for="help_for_custom_options">
                           <?=gettext("Enter any additional options you would like to add to the configuration file here."); ?>
                         </div>
@@ -1535,9 +1559,9 @@ endif; ?>
                     <tr id="comboboxVerbosityLevel">
                       <td style="width:22%"><a id="help_for_verbosity_level" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Verbosity level");?></td>
                       <td>
-                        <select name="verbosity_level" class="form-control">
+                        <select name="verbosity_level" class="selectpicker">
 <?php
-                        foreach ($openvpn_verbosity_level as $verb_value => $verb_desc) :
+                        foreach (openvpn_verbosity_level() as $verb_value => $verb_desc):
                             $selected = '';
                             if ($pconfig['verbosity_level'] == $verb_value) {
                                 $selected = 'selected="selected"';
@@ -1570,10 +1594,21 @@ endif; ?>
                         </div>
                       </td>
                     </tr>
+                    <tr id="chkboxLoginMatching">
+                      <td style="width:22%"><a id="help_for_cso_login_matching" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Force CSO Login Matching"); ?></td>
+                      <td>
+                        <input name="cso_login_matching" type="checkbox" value="yes" <?=!empty($pconfig['cso_login_matching']) ? "checked=\"checked\"" : "" ;?> />
+                        <div class="hidden" data-for="help_for_cso_login_matching">
+                          <span>
+                            <?=gettext("Use username instead of common name to match client specfic override."); ?><br />
+                          </span>
+                        </div>
+                      </td>
+                    </tr>
                     <tr>
                       <td style="width:22%">&nbsp;</td>
                       <td style="width:78%">
-                        <input name="save" type="submit" class="btn btn-primary" value="<?=gettext("Save"); ?>" />
+                        <input name="save" type="submit" class="btn btn-primary" value="<?=html_safe(gettext('Save')); ?>" />
                         <input name="act" type="hidden" value="<?=$act;?>" />
 <?php
                         if (isset($id) && $a_server[$id]) :?>
@@ -1599,7 +1634,7 @@ endif; ?>
                   <td><?=gettext("Protocol / Port"); ?></td>
                   <td><?=gettext("Tunnel Network"); ?></td>
                   <td><?=gettext("Description"); ?></td>
-                  <td></td>
+                  <td class="text-nowrap"></td>
                 </tr>
                 </thead>
 
@@ -1609,36 +1644,40 @@ endif; ?>
                   foreach ($a_server as $server) :?>
                   <tr>
                     <td>
-                      <a href="#" class="act_toggle" data-id="<?=$i;?>" data-toggle="tooltip" title="<?=(empty($server['disable'])) ? gettext("disable") : gettext("enable");?>">
-                        <span class="glyphicon glyphicon-play <?=(empty($server['disable'])) ? "text-success" : "text-muted";?>"></span>
+                      <a href="#" class="act_toggle" data-id="<?=$i;?>" data-toggle="tooltip" title="<?=(empty($server['disable'])) ? gettext("Disable") : gettext("Enable");?>">
+                        <span class="fa fa-play <?=(empty($server['disable'])) ? "text-success" : "text-muted";?>"></span>
                       </a>
                     </td>
                     <td>
                         <?=htmlspecialchars($server['protocol']);?> / <?=htmlspecialchars($server['local_port']);?>
                     </td>
                     <td>
-                        <?=htmlspecialchars($server['tunnel_network']);?> <?=!empty($server['tunnel_networkv6']) ? "," :""?>
-                        <?=htmlspecialchars($server['tunnel_networkv6']);?>
+                        <?= htmlspecialchars($server['tunnel_network'])  ?>
+                        <?= !empty($server['tunnel_networkv6']) && !empty($server['tunnel_network']) ? ',' : '' ?>
+                        <?= htmlspecialchars($server['tunnel_networkv6']) ?>
                     </td>
                     <td>
                         <?=htmlspecialchars($server['description']);?>
                     </td>
-                    <td>
-                        <a href="vpn_openvpn_server.php?act=edit&amp;id=<?=$i;?>" title="<?=gettext("edit server"); ?>" class="btn btn-default btn-xs"><span class="glyphicon glyphicon-pencil"></span></a>
-                        <a id="del_<?=$i;?>" title="<?=gettext("delete server"); ?>" class="act_delete btn btn-default btn-xs"><span class="fa fa-trash text-muted"></span></a>
+                    <td class="text-nowrap">
+                        <a href="vpn_openvpn_server.php?act=edit&amp;id=<?=$i;?>"  title="<?= html_safe(gettext('Edit')) ?>" data-toggle="tooltip" class="btn btn-default btn-xs"><i class="fa fa-pencil fa-fw"></i></a>
+                        <a id="del_<?=$i;?>" title="<?= html_safe(gettext('Delete')) ?>" data-toggle="tooltip" class="act_delete btn btn-default btn-xs"><i class="fa fa-trash fa-fw"></i></a>
+                        <a href="vpn_openvpn_server.php?act=new&amp;dup=<?=$i;?>" class="btn btn-default btn-xs" data-toggle="tooltip" title="<?= html_safe(gettext('Clone')) ?>">
+                          <span class="fa fa-clone fa-fw"></span>
+                        </a>
                     </td>
                   </tr>
 <?php
                   $i++;
                   endforeach;?>
-                  <tr><td colspan="5">&nbsp;</td></tr>
+                  <tr>
+                    <td colspan="5">
+                      <a href="wizard.php?xml=openvpn" class="btn btn-default">
+                        <i class="fa fa-magic fa-fw"></i> <?= gettext('Use a wizard to setup a new server') ?>
+                       </a>
+                    </td>
+                  </tr>
                 </tbody>
-                <tfoot>
-                  <tr><td colspan="5">
-                    <a href="wizard.php?xml=openvpn" class="btn btn-default btn-xs"><span class="fa fa-magic"></span></a>
-                    &nbsp;<?=gettext("Use a wizard to setup a new server");?>
-                  </td></tr>
-                </tfoot>
               </table>
             </div>
           </section>
